#
# spec file for package caja
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname libcaja-extension1
%define typelib typelib-1_0-Caja-2_0
%define _version 1.20
Name:           caja
Version:        1.20.2
Release:        lp151.3.4
Summary:        File manager for the MATE desktop
License:        GPL-2.0-only AND LGPL-2.0-only
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         http://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE caja-gtk-3.20.patch -- Restore GLib 2.48 and GTK+ 3.20 support.
Patch0:         caja-gtk-3.20.patch
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(gail)
BuildRequires:  pkgconfig(gio-2.0) >= 2.48
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sm)
Recommends:     %{name}-lang
# mate-file-manager was last used in openSUSE 13.1.
Provides:       mate-file-manager = %{version}
Obsoletes:      mate-file-manager < %{version}
Obsoletes:      mate-file-manager-lang < %{version}

%description
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%lang_package

%package devel
Summary:        Caja development files
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       %{name} = %{version}
# mate-file-manager-devel was last used in openSUSE 13.1.
Provides:       mate-file-manager-devel = %{version}
Obsoletes:      mate-file-manager-devel < %{version}

%description devel
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%package -n %{lname}
Summary:        Caja shared libraries
Group:          System/Libraries
Requires:       %{name}-gschemas >= %{version}

%description -n %{lname}
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

# Needed for using pluma as standalone from MATE.

%package gschemas
Summary:        Caja GSchemas
Group:          System/Libraries
Obsoletes:      mate-file-manager < %{version}
# caja-gsettings-schemas was last used in openSUSE Leap 42.1.
Obsoletes:      %{name}-gsettings-schemas < %{version}
Provides:       %{name}-gsettings-schemas = %{version}
%glib2_gsettings_schema_requires

%description gschemas
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

This package provides the GSettings schemas for Caja.

%package -n %{typelib}
Summary:        MATE file manager typelib
Group:          System/GUI/Other

%description -n %{typelib}
Caja is the official file manager for the MATE desktop. It allows to
browse directories, preview files and launch applications associated
with them. It is also responsible for handling the icons on the MATE
desktop. It works on local and remote filesystems.

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-update-mimedb \
  --disable-static        \
  --enable-introspection
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name}
find %{buildroot} -type f -name "*.la" -delete -print
# Create extensions directories.
mkdir -p %{buildroot}%{_libdir}/caja/extensions-2.0/ \
  %{buildroot}%{_datadir}/caja/extensions/ \
  %{buildroot}%{_datadir}/caja-extensions/

%suse_update_desktop_file caja-autorun-software
%suse_update_desktop_file caja-browser
%suse_update_desktop_file caja-computer
%suse_update_desktop_file caja-file-management-properties
%suse_update_desktop_file caja-folder-handler
%suse_update_desktop_file caja-home
%suse_update_desktop_file caja
%suse_update_desktop_file mate-network-scheme

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%post gschemas
%glib2_gsettings_schema_post

%postun gschemas
%glib2_gsettings_schema_postun
%endif

%files
%if 0%{?suse_version} >= 1500
%license COPYING COPYING.EXTENSIONS COPYING.LIB
%else
%doc COPYING COPYING.EXTENSIONS COPYING.LIB
%endif
%doc AUTHORS NEWS
%{_bindir}/caja
%{_bindir}/caja-autorun-software
%{_bindir}/caja-connect-server
%{_bindir}/caja-file-management-properties
%{_datadir}/caja/
%{_datadir}/dbus-1/services/org.mate.freedesktop.FileManager1.service
%{_datadir}/applications/caja-autorun-software.desktop
%{_datadir}/applications/caja-browser.desktop
%{_datadir}/applications/caja-computer.desktop
%{_datadir}/applications/caja-file-management-properties.desktop
%{_datadir}/applications/caja-folder-handler.desktop
%{_datadir}/applications/caja-home.desktop
%{_datadir}/applications/caja.desktop
%{_datadir}/applications/mate-network-scheme.desktop
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/pixmaps/*
%{_datadir}/mime/packages/*
%{_mandir}/man?/*.?%{?ext_man}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/caja.appdata.xml
# Own common extensions directories.
%dir %{_libdir}/caja/
%dir %{_libdir}/caja/extensions-2.0/
%dir %{_datadir}/caja/extensions/
%dir %{_datadir}/caja-extensions/

%files lang -f caja.lang

%files -n %{typelib}
%{_libdir}/girepository-1.0/Caja-2.0.typelib

%files -n %{lname}
%{_libdir}/*.so.*

%files gschemas
%{_datadir}/glib-2.0/schemas/*.xml

%files devel
%{_datadir}/gtk-doc/html/libcaja-extension/
%{_includedir}/caja/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libcaja-extension.pc
%{_datadir}/gir-1.0/Caja-2.0.gir

%changelog
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.2 (changes since 1.20.0):
  * Remove a runtime warning in usage of
    caja_clipboard_set_up_editable.
  * Can select all the search keywords with Ctrl+a.
  * Fix backgrounds and emblems dialogue content rendering.
  * Fix warnings from HiDPI commits.
  * sidebar: Respect sidebar dimensions on HiDPI.
  * HiDPI: Convert Pixbufs to Cairo Surfaces.
  * general: Use gdk_monitor_get_scale_factor.
  * list-view: Use the cairo surface as a drag icon.
  * Scale screen dimensions.
  * icon-info: Hash/store icons using scale factor as well as size.
  * file: Support HiDPI for thumbnails images.
  * properties-window: Support HiDPI for the properties window
    icon.
  * Support HiDPI icons.
  * canvas-container: Listen to scale factor to invalidate icons.
  * canvas-item: Use gtk_render_icon_surface for the DnD surface.
  * desktop-canvas-view: Scale desktop workarea.
  * modify code error: End the statement with a semicolon.
  * Update translations.
- Rebase caja-gtk-3.20.patch.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Use gtk+-3 bookmarks location.
  * Expand grid width to canvas.
  * Use atk_component_get_extents instead of
    atk_component_get_position.
  * don't parse .hidden files manually - GIO does it since 2.36.
  * Don't check the nonexistent MATE22_USER_DIR env var.
  * Don't check the nonexistent ~/.mate2 directory.
  * eel-accessibility: Remove unused code and outdated comments.
  * eel: Queue resizes on the canvas as elements change visibility.
  * Add size_request to IconContainer to work around unncecessary
    relayouting.
  * eel: Remove unneeded #include with condition.
  * eel: Remove some unused code from eel-gdk-pixbuf-extensions.
  * gtk 3.22: Avoid deprecated gdk_screen_get_monitor_ functions.
  * Refresh all rows on zoom change.
  * Force widget redraw on zoom.
  * libcaja-private: Remove wrong link from internal README.
  * private: Ensure we allow launching .desktop files from trusted
    symlinks.
  * Fix scaling the desktop wallpaper not working.
  * Avoid deprecated gdk_screen_width/height(),
    gdk_screen_get_width/height(), gdk_screen_make_display_name().
  * libegg: Replace deprecated gtk_drag_begin()
  * eggsmclient: Fix a build warning because of -Wcomment.
  * Don't use deprecated gtk_show_uri.
  * Avoid deprecated gdk_screen_get_number().
  * Add a feature: Present the size on the drive of files as we
    present the size of the file.
  * Reword the Size on Disk column description a bit.
  * Make sure scaling the desktop wallpaper works in all monitors.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * caja-places-sidebar: Fix refusal to unmount when sidebar is
    wide.
  * caja-places-sidebar: Disable the overlay scrollbar.
  * Require GTK+ 3.22 and GLib 2.50.
  * Fix tasklist icon change when opening new tab.
  * Include local files with "" instead of <>.
  * search_dispose and search_finilize can't be run after search
    had finished.
  * Add a missing window icon to the About dialogue for extensions.
  * Move libegg to the top srcdir and drop some leftovers.
  * Remove the +x attr from source files.
  * Restore Polish translation credits from GNOME.
  * Update translations.
- Add caja-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20 support.
- Remove caja-gtk3-bookmarks.patch: fixed upstream.
- Make the library package require caja-gschemas less strictly
  version-wise.
* Tue Nov 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.5:
  * Fix wrong behaviour with the "enter" key when renaming files in
    list view.
  * Open a directory in new window: [ctrl] + [shift] + [w].
  * zoom-control: Change zoom with mousewheel scroll over button.
  * View -> Visible Columns: Fix vertical expand of dialogue
    content.
  * Fix wrong <Shift+Del> behaviour when renaming files.
  * Fix high cpu when loading background image.
  * icon-dnd: Remove a hardcoded highlight frame.
  * list view: Fix large icon margins on zooming out.
  * Remove a weird +x attribute from a source file.
* Thu Aug 31 2017 sor.alexei@meowr.ru
- Update to version 1.18.4:
  * Fix zoom in list-view.
  * pathbar: Enable mousewheel scrolling like it was with GTK+2.
  * open-with-dialog: Set max-char-width for a label.
  * Fix "Open With" dialog ue"Open" button's text misalignment.
  * caja-pathbar: Fix off-by-one error.
  * Fix browsing/autorun media on insertion.
  * Fix vertical Compact View scrolling in
    fm_icon_view_scroll_event().
* Thu May 11 2017 sor.alexei@meowr.ru
- Update to version 1.18.3:
  * Restore D-Bus interface initialisation.
  * CSS: Load a different caja-desktop.css with GTK+ 3.14.
  * file: Make caja_file_get_gicon return custom icons too
    (gh#mate-desktop/caja#765).
  * Open With dialogue: Force the icon size.
  * Show correct right-click menu after making a selection.
- Add caja-gtk3-bookmarks.patch: Use the Gtk3 bookmarks location
  (commit 65f573c).
* Sat Apr 15 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Icon and compact view: Fix scrolling and renaming in large
    directories.
  * IconCanvasItem: Fix overlapping filenames on hover.
* Tue Apr  4 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Fix a build warning.
  * search: Add tag support (xattr::xdg.tags).
  * Fix broken rename in list view by selectin file name cell.
  * property-browser: Add style class frame to scrolledwindows.
  * caja-application.c: Fix an uninitialised variable.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require libmate-desktop >= 1.17.3.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Port from libunique to GtkApplication.
  * Implement copy queue and pausing.
  * Add an option for asking confirmation before moving files to
    trash.
  * Add support for back/forward mouse buttons for directory
    navigation.
  * Add a notification when ejected drives are safe to unplug
    (and require libnotify at build time).
  * Add a --force-desktop command line option to make Caja always
    manage the desktop.
  * Add an ability to get feedback from Orca when additional icons
    are selected/deselected.
  * Drop the metadata converting tool.
  * Fix crossfade issues with recent GTK+ versions.
  * Fix more graphics issues to allow Caja to use background for
    directory windows.
  * Fix some more GTK+ deprecations and runtime warnings.
  * Schema: some fixes and cleanups.
  * Update translations.
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.16.2:
  * List view: Show/hide columns instead of appending/removing them
    (fixes crash when moving between trash and other directory with
    GTK+3).
  * Icon view: Fix accessibility issues.
  * Icon and compact views: Fix moving to next/previous row (or
    column) with right/left (or down/up) keys.
  * Preferences dialogue: Fix vertical expand of content with
    window resize.
  * Show "Open with" menu item and "Open with" tab in properties
    window for .desktop and .theme files.
  * Fix cursor refresh issues on directory change in single click
    mode.
  * Fix runtime warnings on window closing and Caja exit.
  * GTK+3: Fix mousewheel scrolling in compact view.
  * GTK+3: Fix visual issues when renaming files.
  * GTK+3: Force the X11 backend.
  * Some more fixes and cleanups.
* Tue Oct 18 2016 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Fix a regression that sometimes caused visual glitches when
    selecting icons.
  * GTK+3: Some CSS adjustments.
  * GTK+3: Fix accessibility on desktop (for Orca).
  * GTK+3: Fix several runtime warnings.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Use GtkAboutDialog instead of MateAboutDialog.
  * Pathbar: Always show right arrow button.
  * Fix changing taskbar icon when switching between tabs with
    different icons.
  * Fix lots of warnings when building docs for libcaja-extension.
  * GTK+3: Add style classes for elements of pathbar.
  * GTK+3: Fix drawing and changing of desktop background with
    Gtk 3.21.
  * GTK+3: Fix a large amount of deprecations.
  * Some more fixes and cleanups.
  * Update translations.
* Wed Aug 10 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * prefs dialog: Don't crash on toggling "Show hidden and backup
    files".
  * GTK+-3 theming: Add a CSS file for caja, and initialise it at
    startup.
  * GTK+3: Add style class caja-desktop-window at top level.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Drop MateConf migration script.
  * Allow closing tabs on middle-click.
  * List Python extensions separately in extensions list.
  * GTK+3: Add several style classes to simplify theming.
  * GTK+3: Fix desktop flash issue.
  * GTK+3: A lot of deprecation fixes.
  * Some more fixes and cleanups.
  * Update translations.
  * Add Changelog generation.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to 1.12.7:
  * Fix remaining random changes of font color in icon view.
* Tue Mar 15 2016 sor.alexei@meowr.ru
- Update to 1.12.6:
  * Really fix loading multiple python extensions.
* Mon Mar 14 2016 sor.alexei@meowr.ru
- Update to 1.12.5:
  * Fix loading multiple Python extensions.
  * GTK+3: fix crash on Ctrl + scroll wheel.
- Rename caja-gsettings-schemas package to caja-gschemas.
* Thu Feb 18 2016 sor.alexei@meowr.ru
- Update to 1.12.4:
  * Fix random crash on startup when python-caja extension is
    enabled.
  * Fix crash when restoring file with special characters from
    trash.
  * Fix few memleaks.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to 1.12.3:
  * Fix wrong text colour in icon view with some light themes.
  * Fix crash due to unneeded assert.
* Wed Dec 23 2015 sor.alexei@meowr.ru
- Update 1.12.2:
  * Set smclient mode to "no restart" when either running as root
    or on other desktops.
  * Properties -> custom icon dialog: add missing /usr/share/icons/
    to Places.
  * Some other fixes.
* Sat Dec 12 2015 p.drouand@gmail.com
- Remove useless pkgconfig(pangox) requirement
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Assorted bugfixes.
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * GTK+3 fixes.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Connect to server dialog: add support for AFP.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Switch to org.gnome.SessionManager for logout/suspend inhibit.
  * Improve multi-monitor support.
  * Some UI fixes.
* Thu Sep 24 2015 sor.alexei@meowr.ru
- Update to 1.10.4:
  * Fix a crash when using undo following a file deletion.
* Tue Jul 21 2015 sor.alexei@meowr.ru
- Update to 1.10.3:
  * File properties dialog: bring back missing Notes and
    Image Properties tabs.
* Fri Jul 17 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Places sidebar: enable both creating bookmarks and dropping
    files.
  * Compact view: don't auto-scroll to the right on long filenames.
  * Don't manage desktop and exit with last window when either
    running as root or on other desktops.
  * Fix double-click behaviour when clicking on a folder and then
    on a file / directory inside it.
  * GTK+3 fixes.
  * Update translations update.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Do not automount USB flash drives and CD/DVD drives while
    session is locked.
  * Revert dropping of files to Bookmarks sidebar.
  * UI bugfixes.
- Spec cleanup.
* Tue Apr 14 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * Bug fixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bug fixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Own the new caja extensions directory
* Tue Jan 13 2015 p.drouand@gmail.com
- Update to version 1.9.4 (unstable)
  + Allow extensions to be enabled/disabled at runtime
  + Bugfixes
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.3 (unstable)
  + Allow extensions to be enabled/disabled at runtime
  + Bugfixes
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + bugfixes release
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.2
  + limit deep scount (folder contents and size) to one filesystem
  + Handle metadata key deletions
  + Propagate button-release event when ejecting
  + Fix text renderinf on no background
* Sat Apr 26 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + accessibility improvements
  + fixed x-caja-desktop issue
  + removed ConsoleKit usage
  + show trash icon in tree side panel
* Mon Mar 10 2014 p.drouand@gmail.com
- Add several obsoletes to avoid a lot of conflicts with
  mate-file-manager
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + add GTK3 support
  + re add bookmark section in connect server dialog
  + add option to show file sizes with IEC units instead of SI units
  + add "Open parent location" in menu if we are in search view
* Mon Feb 10 2014 p.drouand@gmail.com
- Initial release (version 1.7.2)
